6.20   os32: errno(3)

NOME

    errno - numero dell'ultimo errore riportato

SINTASSI

    #include <errno.h>

DESCRIZIONE

    Attraverso l'inclusione del file errno.h, si ottiene la dichiarazione della
    variabile <errno>. In pratica, per os32 viene dichiarata cosi`:

    extern int errno;

    Per annotare un errore si assegna un valore numerico a questa variabile. Il
    valore numerico in questione rappresenta sinteticamente la descrizione
    dell'errore; pertanto, si utilizzano per questo delle macro-variabili,
    dichiarate tutte nel file errno.h. Nell'esempio seguente si annota l'errore
    <ENOMEM>, corrispondente alla descrizione "Not enough space", ovvero
    "spazio insufficiente":

    errno = ENOMEM;

    Dal momento che in questo modo viene comunque a mancare un riferimento al
    sorgente e alla posizione in cui l'errore si e` manifestato, la libreria di
    os32 aggiunge la macroistruzione <errset()>, la quale pero` non fa parte
    dello standard. Si usa cosi`:

    errset (ENOMEM);

    La macroistruzione <errset()> aggiorna la variabile <errln> e l'array
    <errfn[]>, rispettivamente con il numero della riga di codice in cui si e`
    manifestato il problema e il nome della funzione che lo contiene. Con
    queste informazioni, la funzione perror(3) [6.90] puo` visualizzare piu`
    dati.

    Pertanto, nel codice di os32, si usa sempre la macroistruzione <errset()>,
    invece di assegnare semplicemente un valore alla variabile <errno>.

ERRORI

    Gli errori previsti dalla libreria di os32 sono riassunti dalla tabella
    successiva. La prima parte contiene gli errori definiti dallo standard
    POSIX, ma solo alcuni di questi vengono usati effettivamente nella
    libreria, data la limitatezza di os32.

    Valore di     Definizione
    <errno>
    E2BIG         Argument list too long.

    EACCES        Permission denied.

    EADDRINUSE    Address in use.

    EADDRNOTAVAIL Address not available.

    EAFNOSUPPORT  Address family not supported.

    EAGAIN        Resource unavailable, try again.

    EALREADY      Connection already in progress.

    EBADF         Bad file descriptor.

    EBADMSG       Bad message.

    EBUSY         Device or resource busy.

    Valore di    Definizione
    <errno>
    ECANCELED    Operation canceled.

    ECHILD       No child processes.

    ECONNABORTED Connection aborted.

    ECONNREFUSED Connection refused.

    ECONNRESET   Connection reset.

    EDEADLK      Resource deadlock would occur.

    EDESTADDRREQ Destination address required.

    EDOM         Mathematics argument out of domain of function.

    EDQUOT       Reserved.

    EEXIST       File exists.

    Valore di    Definizione
    <errno>
    EFAULT       Bad address.

    EFBIG        File too large.

    EHOSTUNREACH Host is unreachable.

    EIDRM        Identifier removed.

    EILSEQ       Illegal byte sequence.

    EINPROGRESS  Operation in progress.

    EINTR        Interrupted function.

    EINVAL       Invalid argument.

    EIO          I/O error.

    EISCONN      Socket is connected.

    Valore di    Definizione
    <errno>
    EISDIR       Is a directory.

    ELOOP        Too many levels of symbolic links.

    EMFILE       Too many open files.

    EMLINK       Too many links.

    EMSGSIZE     Message too large.

    EMULTIHOP    Reserved.

    ENAMETOOLONG Filename too long.

    ENETDOWN     Network is down.

    ENETRESET    Connection aborted by network.

    ENETUNREACH  Network unreachable.

    Valore di Definizione
    <errno>
    ENFILE    Too many files open in system.

    ENOBUFS   No buffer space available.

    ENODATA   No message is available on the stream head read queue.

    ENODEV    No such device.

    ENOENT    No such file or directory.

    ENOEXEC   Executable file format error.

    ENOLCK    No locks available.

    ENOLINK   Reserved.

    ENOMEM    Not enough space.

    ENOMSG    No message of the desired type.

    Valore di   Definizione
    <errno>
    ENOPROTOOPT Protocol not available.

    ENOSPC      No space left on device.

    ENOSR       No stream resources.

    ENOSTR      Not a stream.

    ENOSYS      Function not supported.

    ENOTCONN    The socket is not connected.

    ENOTDIR     Not a directory.

    ENOTEMPTY   Directory not empty.

    ENOTSOCK    Not a socket.

    ENOTSUP     Not supported.

    Valore di       Definizione
    <errno>
    ENOTTY          Inappropriate I/O control operation.

    ENXIO           No such device or address.

    EOPNOTSUPP      Operation not supported on socket.

    EOVERFLOW       Value too large to be stored in data type.

    EPERM           Operation not permitted.

    EPIPE           Broken pipe.

    EPROTO          Protocol error.

    EPROTONOSUPPORT Protocol not supported.

    EPROTOTYPE      Protocol wrong type for socket.

    ERANGE          Result too large.

    Valore di   Definizione
    <errno>
    EROFS       Read-only file system.

    ESPIPE      Invalid seek.

    ESRCH       No such process.

    ESTALE      Reserved.

    ETIME       Stream ioctl() timeout.

    ETIMEDOUT   Connection timed out.

    ETXTBSY     Text file busy.

    EWOULDBLOCK Operation would block (may be the same as EAGAIN).

    EXDEV       Cross-device link.

    La tabella successiva raccoglie le definizioni degli errori aggiuntivi,
    specifici di os32.

    Valore di                 Definizione
    <errno>
    EUNKNOWN                  Unknown error.

    E_NO_MEDIUM               No medium found.

    E_MEDIUM                  Medium reported error.

    E_FILE_TYPE               File type not compatible.

    E_ROOT_INODE_NOT_CACHED   The root directory inode is not cached.

    E_CANNOT_READ_SUPERBLOCK  Cannot read super block.

    E_MAP_INODE_TOO_BIG       Map inode too big.

    E_MAP_ZONE_TOO_BIG        Map zone too big.

    E_DATA_ZONE_TOO_BIG       Data zone too big.

    E_CANNOT_FIND_ROOT_DEVICE Cannot find root device.

    E_CANNOT_FIND_ROOT_INODE  Cannot find root inode.

    Valore di               Definizione
    <errno>
    E_FILE_TYPE_UNSUPPORTED File type unsupported.

    E_ENV_TOO_BIG           Environment too big.

    E_LIMIT                 Exceeded implementation limits.

    E_NOT_MOUNTED           Not mounted.

    E_NOT_IMPLEMENTED       Not implemented.

    E_HARDWARE_FAULT        Hardware fault.

    E_DRIVER_FAULT          Driver fault.

    E_PIPE_FULL             Pipe full.

    E_PIPE_EMPTY            Pipe empty.

FILE SORGENTI

    lib/errno.h [13.5]

    lib/errno/errno.c [13.5.1]

VEDERE ANCHE

    perror(3) [6.90], strerror(3) [6.120].

